@@ -3,7 +3,7 @@ package POE::Component::IRC::Common;
 use strict;
 use warnings;
 
-our $VERSION = '5.17';
+our $VERSION = '5.98';
 
 require Exporter;
 use base qw(Exporter);
@@ -210,11 +210,11 @@ sub strip_color {
     my $string = shift;
     
     # mIRC colors
-    $string =~ s/\x03(?:\d{1,2}(?:,\d{1,2})?)?//g;
+    $string =~ s/\x03(?:,\d{1,2}|\d{1,2}(?:,\d{1,2})?)?//g;
     $string =~ s/\x0f//g;
     
     # RGB colors supported by some clients
-    $string =~ s/\x04[0-9a-f]{0,6}//ig;
+    $string =~ s/\x04[0-9a-fA-F]{0,6}//ig;
     
     return $string;
 }
@@ -363,8 +363,8 @@ __END__
 
 =head1 NAME
 
-POE::Component::IRC::Common - provides a set of common functions for the
-L<POE::Component::IRC|POE::Component::IRC> suite.
+POE::Component::IRC::Common - Provides a set of common functions for the
+L<POE::Component::IRC|POE::Component::IRC> suite
 
 =head1 SYNOPSIS
 
@@ -474,8 +474,9 @@ Takes a list representing an IRC mode line. Returns a hashref. If the modeline
 couldn't be parsed the hashref will be empty. On success the following keys
 will be available in the hashref:
 
- 'modes', an arrayref of normalised modes;
- 'args', an arrayref of applicable arguments to the modes;
+B<'modes'>, an arrayref of normalised modes;
+
+B<'args'>, an arrayref of applicable arguments to the modes;
 
 Example:
 
@@ -504,14 +505,17 @@ Takes two parameters, a string representing an IRC mask ( it'll be processed
 with parse_ban_mask() to ensure that it is normalised ) and something to match
 against the IRC mask, such as a nick!user@hostname string. Returns a true
 value if they match, a false value otherwise. Optionally, one may pass the
-casemapping ( see u_irc() ), as this function uses u_irc() internally.
+casemapping (see L<C<u_irc>|/"u_irc">), as this function uses C<u_irc>
+internally.
 
 =head2 C<matches_mask_array>
 
 Takes two array references, the first being a list of strings representing
-IRC mask, the second a list of somethings to test against the masks. Returns
+IRC masks, the second a list of somethings to test against the masks. Returns
 an empty hashref if there are no matches. Otherwise, the keys will be the
 masks matched, each value being an arrayref of the strings that matched it.
+Optionally, one may pass the casemapping (see L<C<u_irc>|/"u_irc">), as
+this function uses C<u_irc> internally.
 
 =head2 C<parse_user>
 
