@@ -5,16 +5,17 @@ use warnings;
 use Carp;
 use POE qw(Wheel::FollowTail);
 use POE::Component::IRC::Plugin qw( :ALL );
-use vars qw($VERSION);
 
-$VERSION = '0.02';
+our $VERSION = '5.98';
 
 sub new {
-    my ($package, %args) = @_;
+    my ($package) = shift;
+    croak "$package requires an even number of arguments" if @_ & 1;
+    my %args = @_;
     $args{lc $_} = delete $args{$_} for keys %args;
     
     if (!$args{filename} || ! -e $args{filename}) {
-        croak "$package requires a valid 'filename' attribute\n"
+        die "$package requires a valid 'filename' attribute";
     }
     
     return bless \%args, $package;
@@ -65,20 +66,20 @@ sub _shutdown {
 
 sub _input {
     my ($kernel, $self, $input) = @_[KERNEL, OBJECT, ARG0];
-    $self->{irc}->_send_event( 'irc_tail_input', $self->{filename}, $input );
+    $self->{irc}->send_event( 'irc_tail_input', $self->{filename}, $input );
     return;
 }
 
 sub _error {
     my ($kernel, $self) = @_[KERNEL, OBJECT];
-    $self->{irc}->_send_event( 'irc_tail_error', $self->{filename}, @_[ARG0..ARG2] );
+    $self->{irc}->send_event( 'irc_tail_error', $self->{filename}, @_[ARG0..ARG2] );
     $kernel->yield('_shutdown','TERM');
     return;
 }
 
 sub _reset {
     my ($kernel, $self) = @_[KERNEL, OBJECT];
-    $self->{irc}->_send_event( 'irc_tail_reset', $self->{filename} );
+    $self->{irc}->send_event( 'irc_tail_reset', $self->{filename} );
     return;
 }
 
@@ -153,45 +154,40 @@ of an ever-growing file
 
 POE::Component::IRC::Plugin::FollowTail is a L<POE::Component::IRC|POE::Component::IRC>
 plugin that uses L<POE::Wheel::FollowTail|POE::Wheel::FollowTail> to follow
-the end of an ever-growing file. It generates 'irc_tail_' prefixed events for
+the end of an ever-growing file. It generates C<irc_tail_> prefixed events for
 each new record that is appended to its file.
 
-=head1 CONSTRUCTOR
+=head1 METHODS
 
-=over
-
-=item C<new>
+=head2 C<new>
 
 Takes two arguments:
 
-'filename', the name of the file to tail, mandatory;
+B<'filename'>, the name of the file to tail, mandatory;
 
-'filter', a POE::Filter object to pass to POE::Wheel::FollowTail, optional;
+B<'filter'>, a POE::Filter object to pass to POE::Wheel::FollowTail, optional;
 
-=back
+Returns a plugin object suitable for feeding to
+L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
-=head1 EVENTS
+=head1 OUTPUT
 
 The plugin generates the following additional
 L<POE::Component::IRC|POE::Component::IRC> events:
 
-=over
+=head2 C<irc_tail_input>
 
-=item C<irc_tail_input>
+Emitted for every complete record read. C<ARG0> will be the filename,
+C<ARG1> the record which was read.
 
-Emitted for every complete record read. ARG0 will be the filename, ARG1 the
-record which was read.
+=head2 C<irc_tail_error>
 
-=item C<irc_tail_error>
+Emitted whenever an error occurs. C<ARG0> will be the filename, C<ARG1>
+and C<ARG2> hold numeric and string values for $!, respectively.
 
-Emitted whenever an error occurs. ARG0 will be the filename, ARG1 and ARG2 hold
-numeric and string values for $!, respectively.
+=head2 C<irc_tail_reset>
 
-=item C<irc_tail_reset>
-
-Emitted every time a file is reset. ARG0 will be the filename.
-
-=back
+Emitted every time a file is reset. C<ARG0> will be the filename.
 
 =head1 AUTHOR
 
