@@ -2,12 +2,15 @@ package POE::Component::IRC::Plugin::NickReclaim;
 
 use strict;
 use warnings;
+use Carp;
 use POE::Component::IRC::Plugin qw(:ALL);
 
-our $VERSION = '1.3';
+our $VERSION = '5.98';
 
 sub new {
-    my ($package, %args) = @_;
+    my ($package) = shift;
+    croak "$package requires an even number of arguments" if @_ & 1;
+    my %args = @_;
     $args{ lc $_ } = delete $args{$_} for keys %args;
 
     if (!defined $args{poll} || $args{poll} !~ /^\d+$/) {
@@ -51,7 +54,7 @@ sub PCI_register {
 ##############
 sub U_nick {
     my $self = shift;
-    my ($nick) = $ {$_[1 ]} =~ /^NICK\s+(.+)/i;
+    my ($nick) = $ {$_[1 ]} =~ /^NICK +(.+)/i;
     
     return PCI_EAT_NONE if exists $self->{_claims}{ $nick };
 
@@ -122,14 +125,14 @@ __END__
 =head1 NAME
 
 POE::Component::IRC::Plugin::NickReclaim - A PoCo-IRC plugin for reclaiming
-nickname.
+your nickname
 
 =head1 SYNOPSIS
 
  use strict;
  use warnings;
  use POE qw(Component::IRC Component::IRC::Plugin::NickReclaim);
-
+i
  my $nickname = 'Flibble' . $$;
  my $ircname = 'Flibble the Sailor Bot';
  my $ircserver = 'irc.blahblahblah.irc';
@@ -163,13 +166,15 @@ nickname.
 
 =head1 DESCRIPTION
 
-POE::Component::IRC::Plugin::NickReclaim - A L<POE::Component::IRC> plugin
-automagically deals with your bot's nickname being in use and reclaims it when
-it becomes available again.
+POE::Component::IRC::Plugin::NickReclaim - A
+L<POE::Component::IRC|POE::Component::IRC> plugin automagically deals with
+your bot's nickname being in use and reclaims it when it becomes available
+again.
 
 It registers and handles 'irc_433' events. On receiving a 433 event it will
-reset the nickname to the 'nick' specified with spawn() or connect(), appended
-with an underscore, and then poll to try and change it to the original nickname. 
+reset the nickname to the 'nick' specified with C<spawn> or C<connect>,
+appendedwith an underscore, and then poll to try and change it to the
+original nickname. 
 
 =head1 METHODS
 
@@ -177,10 +182,10 @@ with an underscore, and then poll to try and change it to the original nickname.
 
 Takes one optional argument:
 
-'poll', the number of seconds between nick change attempts, default is 30;
+B<'poll'>, the number of seconds between nick change attempts, default is 30;
 
 Returns a plugin object suitable for feeding to
-L<POE::Component::IRC|POE::Component::IRC>'s plugin_add() method.
+L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
 =head1 AUTHOR
 
