@@ -5,9 +5,8 @@ use warnings;
 use Carp;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Common qw( :ALL );
-use vars qw($VERSION);
 
-$VERSION = '5.76';
+our $VERSION = '5.98';
 
 BEGIN { 
     # Turn on the debugger's symbol source tracing
@@ -20,7 +19,9 @@ BEGIN {
 }
 
 sub new {
-    my ($package, %args) = @_;
+    my ($package) = shift;
+    croak "$package requires an even number of arguments" if @_ & 1;
+    my %args = @_;
     $args{ lc $_ } = delete $args{ $_ } for keys %args;
     return bless \%args, $package;
 }
@@ -32,8 +33,8 @@ sub new {
 sub PCI_register {
     my ($self, $irc) = @_;
 
-    if ( !$irc->isa('POE::Component::IRC::State') ) {
-        croak __PACKAGE__ . ' requires PoCo::IRC::State or a subclass thereof';
+    if (defined $self->{botowner} && !$irc->isa('POE::Component::IRC::State') ) {
+        die __PACKAGE__ . ' requires PoCo::IRC::State or a subclass thereof';
     }
 
     $self->{irc} = $irc;
@@ -50,7 +51,7 @@ sub PCI_register {
             my $msg = $self->unload(@cmd) ? 'Done.' : 'Nope';
             $self->{irc}->yield($method => $recipient => $msg);
         },
-	PLUGIN_RELOAD => sub {
+        PLUGIN_RELOAD => sub {
             my ($self, $method, $recipient, @cmd) = @_;
             my $msg = $self->reload(@cmd) ? 'Done.' : 'Nope';
             $self->{irc}->yield($method => $recipient => $msg);
@@ -58,7 +59,7 @@ sub PCI_register {
         PLUGIN_LIST => sub {
             my ($self, $method, $recipient, @cmd) = @_;
             my @aliases = keys %{ $self->{irc}->plugin_list() };
-            my $msg = scalar @aliases
+            my $msg = @aliases
                 ? 'Plugins [ ' . join(', ', @aliases ) . ' ]'
                 : 'No plugins loaded.';
             $self->{irc}->yield($method => $recipient => $msg);
@@ -66,7 +67,7 @@ sub PCI_register {
         PLUGIN_LOADED => sub {
             my ($self, $method, $recipient, @cmd) = @_;
             my @aliases = $self->loaded();
-            my $msg = scalar @aliases
+            my $msg = @aliases
                 ? 'Managed Plugins [ ' . join(', ', @aliases ) . ' ]'
                 : 'No managed plugins loaded.';
             $self->{irc}->yield($method => $recipient => $msg);
@@ -90,7 +91,7 @@ sub S_public {
     my $me = $irc->nick_name();
 
     my ($command) = $what =~ m/^\s*\Q$me\E[\:\,\;\.]?\s*(.*)$/i;
-    return PCI_EAT_NONE unless $command and $self->_bot_owner($nick);
+    return PCI_EAT_NONE if !$command || !$self->_bot_owner($nick);
 
     my (@cmd) = split(/ +/, $command);
     my $cmd = uc (shift @cmd);
@@ -148,7 +149,7 @@ sub load {
         if ($@) {
             delete $INC{$module};
             $self->_unload_subs($plugin);
-            croak "$@";
+            die "$@\n";
         }
 
         $object = $plugin->new( @_ );
@@ -195,7 +196,7 @@ sub _unload_subs {
 
     for my $sym ( grep { index( $_, "$file:" ) == 0 } keys %DB::sub ) {
         eval { undef &$sym };
-        carp "$sym: $@" if $@;
+        warn "$sym: $@\n" if $@;
         delete $DB::sub{$sym};
     }
 
@@ -208,10 +209,10 @@ sub reload {
 
     my $plugin_state = $self->{plugins}->{ $desc };
     return if !$plugin_state;
-    carp "Unloading plugin $desc" if $self->{debug};
+    warn "Unloading plugin $desc\n" if $self->{debug};
     return if !$self->unload( $desc );
 
-    carp "Loading plugin $desc " . $plugin_state->{plugin} . ' [ ' . join(', ',@{ $plugin_state->{args} }) . " ]" if $self->{debug};
+    warn "Loading plugin $desc " . $plugin_state->{plugin} . ' [ ' . join(', ',@{ $plugin_state->{args} }) . " ]\n" if $self->{debug};
     return if !$self->load( $desc, $plugin_state->{plugin}, @{ $plugin_state->{args} } );
     return 1;
 }
@@ -227,7 +228,7 @@ __END__
 =head1 NAME
 
 POE::Component::IRC::Plugin::PlugMan - A PoCo-IRC plugin that provides plugin
-management services. 
+management services.
 
 =head1 SYNOPSIS
 
@@ -267,34 +268,26 @@ plugin. It provides support for 'on-the-fly' loading, reloading and unloading
 of plugin modules, via object methods that you can incorporate into your own
 code and a handy IRC interface.
 
-=head1 CONSTRUCTOR
+=head1 METHODS
 
-=over
-
-=item C<new>
+=head2 C<new>
 
 Takes two optional arguments:
 
-'botowner', an IRC mask to match against for people issuing commands via the
+B<'botowner'>, an IRC mask to match against for people issuing commands via the
 IRC interface;
  
-'debug', set to a true value to see when stuff goes wrong;
+B<'debug'>, set to a true value to see when stuff goes wrong;
 
-Not setting a 'botowner' effectively disables the IRC interface. 
+Not setting a B<'botowner'> effectively disables the IRC interface. 
 
-If 'botowner' is specified the plugin checks that it is being loaded into a
+If B<'botowner'> is specified the plugin checks that it is being loaded into a
 L<POE::Component::IRC::State> or sub-class and will fail to load otherwise.
 
 Returns a plugin object suitable for feeding to
-L<POE::Component::IRC|POE::Component::IRC>'s plugin_add() method.
+L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
-=back
-
-=head1 METHODS
-
-=over
-
-=item C<load>
+=head2 C<load>
 
 Loads a managed plugin.
 
@@ -305,7 +298,7 @@ Any other arguments are used as options to the loaded plugin constructor.
 
 Returns true or false depending on whether the load was successfully or not.
 
-=item C<unload>
+=head2 C<unload>
 
 Unloads a managed plugin.
 
@@ -315,7 +308,7 @@ Takes one mandatory argument, a plugin descriptor.
 
 Returns true or false depending on whether the unload was successfully or not.
 
-=item C<reload>
+=head2 C<reload>
 
 Unloads and loads a managed plugin, with applicable plugin options.
 
@@ -323,7 +316,7 @@ Takes one mandatory argument, a plugin descriptor.
 
  $plugin->reload( 'Connector' );
 
-=item C<loaded>
+=head2 C<loaded>
 
 Takes no arguments.
 
@@ -331,40 +324,35 @@ Takes no arguments.
 
 Returns a list of descriptors of managed plugins.
 
-=back
+=head1 INPUT
 
-=head1 IRC INTERFACE
+An IRC interface is enabled by specifying a "botowner" mask to
+L<C<new>|/"new">. Commands may be either invoked via a PRIVMSG directly to
+your bot or in a channel by prefixing the command with the nickname of your
+bot. One caveat, the parsing of the irc command is very rudimentary (it
+merely splits the line on spaces).
 
-The IRC interface is enabled by specifying a "botowner" mask to new(). Commands
-may be either invoked via a PRIVMSG directly to your bot or in a channel by
-prefixing the command with the nickname of your bot. One caveat, the parsing
-of the irc command is very rudimentary ( it merely splits the line on \s+ ). 
+=head2 C<plugin_add>
 
-=over
+Takes the same arguments as C<load>.
 
-=item C<plugin_add>
+=head2 C<plugin_del>
 
-Takes the same arguments as load().
+Takes the same arguments as C<unload>.
 
-=item C<plugin_del>
+=head2 C<plugin_reload>
 
-Takes the same arguments as unload().
+Takes the same arguments as C<reload>.
 
-=item C<plugin_reload>
-
-Takes the same arguments as reload().
-
-=item C<plugin_loaded>
+=head2 C<plugin_loaded>
 
 Returns a list of descriptors of managed plugins.
 
-=item C<plugin_list>
+=head2 C<plugin_list>
 
 Returns a list of descriptors of *all* plugins loaded into the current PoCo-IRC
 component.
 
-=back
-
 =head1 AUTHOR
 
 Chris 'BinGOs' Williams
